Skip site navigation (1)Skip section navigation (2)
Date:      Fri, 3 Jun 2016 05:38:55 GMT
From:      yuanxunzhang@FreeBSD.org
To:        svn-soc-all@FreeBSD.org
Subject:   socsvn commit: r304468 - soc2016/yuanxunzhang/head/usr.sbin/eaps
Message-ID:  <201606030538.u535ctf7017062@socsvn.freebsd.org>

next in thread | raw e-mail | index | archive | help
Author: yuanxunzhang
Date: Fri Jun  3 05:38:54 2016
New Revision: 304468
URL: http://svnweb.FreeBSD.org/socsvn/?view=rev&rev=304468

Log:
  freeBSD:EAPS development

Modified:
  soc2016/yuanxunzhang/head/usr.sbin/eaps/eaps.c

Modified: soc2016/yuanxunzhang/head/usr.sbin/eaps/eaps.c
==============================================================================
--- soc2016/yuanxunzhang/head/usr.sbin/eaps/eaps.c	Fri Jun  3 05:29:46 2016	(r304467)
+++ soc2016/yuanxunzhang/head/usr.sbin/eaps/eaps.c	Fri Jun  3 05:38:54 2016	(r304468)
@@ -108,9 +108,13 @@
 	eaps_new = (struct eaps_d *) malloc (sizeof(struct eaps_d));
 	strlcpy(eaps_new->eaps_name, domain_name, sizeof(eaps_new->eaps_name));
 
 	/* Add to keymap list */
 	SLIST_INSERT_HEAD(&head, eaps_new, eaps_entries);
 
+	if (SLIST_EMPTY(&head)) {
+		printf("No eaps Configuration!\n");
+	}
+	
 	exit(error);
 }
 
@@ -108,9 +108,13 @@
 	strlcpy(eaps_new->eaps_name, domain_name, sizeof(eaps_new->eaps_name));
 
-	/* Add to keymap list */
+	/* Add to eaps list */
 	SLIST_INSERT_HEAD(&head, eaps_new, eaps_entries);
 



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?201606030538.u535ctf7017062>